"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateEntity = exports.updateEntities = exports.clear = exports.removeAll = exports.removeOne = exports.removeMany = exports.mergeEntity = exports.mergeEntities = void 0;
var ActionTypes = require("./actionTypes");
/**
 * Merges many entities at once
 */
function mergeEntities(entityMap) {
    return {
        type: ActionTypes.MERGE_ENTITIES,
        payload: entityMap,
    };
}
exports.mergeEntities = mergeEntities;
/**
 * Merges a field inside an entity
 */
function mergeEntity(domain, id, data) {
    return {
        type: ActionTypes.MERGE_ENTITY,
        payload: {
            domain: domain,
            id: id,
            data: data,
        },
    };
}
exports.mergeEntity = mergeEntity;
/**
 * Removes multiple entities at once (of a single type/domain)
 */
function removeMany(domain, keys) {
    return {
        type: ActionTypes.REMOVE,
        payload: {
            domain: domain,
            keys: keys,
        },
    };
}
exports.removeMany = removeMany;
/**
 * Removes one entity by id
 */
function removeOne(domain, key) {
    return removeMany(domain, [key]);
}
exports.removeOne = removeOne;
/**
 * Removes all entities by domain
 */
function removeAll(domain) {
    return {
        type: ActionTypes.REMOVE_ALL,
        payload: {
            domain: domain,
        },
    };
}
exports.removeAll = removeAll;
/**
 * Clears the whole entity cache
 */
function clear() {
    return {
        type: ActionTypes.CLEAR,
    };
}
exports.clear = clear;
/**
 * Update all entities with the new ones
 */
function updateEntities(entityMap) {
    return {
        type: ActionTypes.UPDATE_ENTITIES,
        payload: entityMap,
    };
}
exports.updateEntities = updateEntities;
/**
 * Update one entities with a new data
 */
function updateEntity(domain, id, data) {
    return {
        type: ActionTypes.UPDATE_ENTITY,
        payload: {
            domain: domain,
            id: id,
            data: data,
        },
    };
}
exports.updateEntity = updateEntity;
//# sourceMappingURL=actions.js.map