"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getIds = exports.getSome = exports.getOne = exports.getDomain = exports.getEntities = void 0;
var ramda_1 = require("ramda");
var EMPTY_OBJECT = {};
/**
 * Get all the entities as Object
 */
exports.getEntities = ramda_1.curry(function (state) { return state.entities; });
/**
 * Get all entities for domain as an object
 */
exports.getDomain = ramda_1.curry(function (domain, state) { return exports.getEntities(state)[domain] || EMPTY_OBJECT; });
/**
 * Get single entity from domain, by it's id
 */
exports.getOne = ramda_1.curry(function (domain, id, state) { return exports.getDomain(domain, state)[id]; });
/**
 * Get the entities with specific ids in a domain
 */
exports.getSome = ramda_1.curry(function (domain, ids, state) {
    var stringIds = ids.map(String);
    var entities = exports.getDomain(domain, state);
    return Object.keys(entities)
        .filter(function (key) {
        return ramda_1.includes(key, stringIds);
    })
        .map(function (key) { return entities[key]; });
});
/**
 * Get ids of the entities inside a domain
 */
exports.getIds = ramda_1.curry(function (domain, state) {
    var entities = exports.getDomain(domain, state);
    return Object.keys(entities) || [];
});
//# sourceMappingURL=selectors.js.map