"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trim = exports.removeOccurrences = exports.replaceDomain = exports.replaceOne = exports.pop = exports.shift = exports.push = exports.unshift = void 0;
var ActionTypes = require("./actionTypes");
/**
 * Prepends an item to the list
 */
function unshift(domain, value) {
    return {
        type: ActionTypes.UNSHIFT,
        payload: {
            domain: domain,
            value: value,
        },
    };
}
exports.unshift = unshift;
/**
 * Appends an item in the right of the list
 */
function push(domain, value) {
    return {
        type: ActionTypes.PUSH,
        payload: {
            domain: domain,
            value: value,
        },
    };
}
exports.push = push;
/**
 * Removes the first value of list
 */
function shift(domain) {
    return {
        type: ActionTypes.SHIFT,
        payload: {
            domain: domain,
        },
    };
}
exports.shift = shift;
/**
 * Removes the last value of list
 */
function pop(domain) {
    return {
        type: ActionTypes.POP,
        payload: {
            domain: domain,
        },
    };
}
exports.pop = pop;
/**
 * Replaces a value in a specific index of the list
 */
function replaceOne(domain, index, value) {
    return {
        type: ActionTypes.REPLACE_ONE,
        payload: {
            domain: domain,
            index: index,
            value: value,
        },
    };
}
exports.replaceOne = replaceOne;
/**
 * Replaces all the domain elements with new ones
 */
function replaceDomain(domain, elements) {
    return {
        type: ActionTypes.REPLACE_DOMAIN,
        payload: {
            domain: domain,
            elements: elements,
        },
    };
}
exports.replaceDomain = replaceDomain;
/**
 * Removes n occurrences of the value in the list
 */
function removeOccurrences(domain, count, value) {
    return {
        type: ActionTypes.REMOVE_OCCURRENCES,
        payload: {
            domain: domain,
            count: count,
            value: value,
        },
    };
}
exports.removeOccurrences = removeOccurrences;
/**
 * Removes all the elements in the list except of the ones
 * included in the specified range
 */
function trim(domain, start, stop) {
    if (stop === void 0) { stop = -1; }
    return {
        type: ActionTypes.TRIM,
        payload: {
            domain: domain,
            start: start,
            stop: stop,
        },
    };
}
exports.trim = trim;
//# sourceMappingURL=actions.js.map