"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
var buildReducer_1 = require("../lib/buildReducer");
var ramda_1 = require("ramda");
var ActionTypes = require("./actionTypes");
var initialState = {};
var removeFirstOccurrence = function (value) { return function (list) {
    return ramda_1.remove(list.indexOf(value), 1, list);
}; };
var removeLastOccurrence = function (value) { return function (list) {
    return ramda_1.remove(list.lastIndexOf(value), 1, list);
}; };
function removeNOccurrences(list, count, value) {
    if (list === void 0) { list = []; }
    if (count === void 0) { count = 0; }
    if (count === 0) {
        return list.filter(function (item) { return item !== value; });
    }
    else {
        var fn = count < 0 ? removeLastOccurrence : removeFirstOccurrence;
        var functions = ramda_1.repeat(fn(value), Math.abs(count));
        return ramda_1.pipe.apply(void 0, functions)(list);
    }
}
var actionHandlers = (_a = {},
    _a[ActionTypes.UNSHIFT] = function (state, action) {
        var _a = action.payload, domain = _a.domain, value = _a.value;
        var prevItems = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, __spreadArrays([value], prevItems), state);
    },
    _a[ActionTypes.PUSH] = function (state, action) {
        var _a = action.payload, domain = _a.domain, value = _a.value;
        var prevItems = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, __spreadArrays(prevItems, [value]), state);
    },
    _a[ActionTypes.SHIFT] = function (state, action) {
        var domain = action.payload.domain;
        var newList = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, ramda_1.tail(newList), state);
    },
    _a[ActionTypes.POP] = function (state, action) {
        var domain = action.payload.domain;
        var list = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, ramda_1.init(list), state);
    },
    _a[ActionTypes.REPLACE_ONE] = function (state, action) {
        var _a = action.payload, domain = _a.domain, value = _a.value, index = _a.index;
        var prevItems = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, ramda_1.update(index, value, prevItems), state);
    },
    _a[ActionTypes.REPLACE_DOMAIN] = function (state, action) {
        var _a = action.payload, domain = _a.domain, elements = _a.elements;
        return ramda_1.assoc(domain, __spreadArrays(elements), state);
    },
    _a[ActionTypes.REMOVE_OCCURRENCES] = function (state, action) {
        var _a = action.payload, domain = _a.domain, count = _a.count, value = _a.value;
        var prevItems = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, removeNOccurrences(prevItems, count, value), state);
    },
    _a[ActionTypes.TRIM] = function (state, action) {
        var _a = action.payload, domain = _a.domain, start = _a.start, stop = _a.stop;
        var prevItems = ramda_1.propOr([], domain, state);
        return ramda_1.assoc(domain, ramda_1.slice(start, stop + 1, prevItems), state);
    },
    _a);
exports.default = buildReducer_1.default(initialState, actionHandlers);
//# sourceMappingURL=reducer.js.map