"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOccurrencesOf = exports.getIndexOf = exports.contains = exports.getRange = exports.getByIndex = exports.getList = void 0;
var ramda_1 = require("ramda");
var root = function (state) { return state.list; };
var EMPTY_ARRAY = [];
/**
 * Get all the elements in a list
 */
exports.getList = ramda_1.curry(function (domain, state) { return ramda_1.propOr(EMPTY_ARRAY, domain, root(state)); });
/**
 * Get the element in a specified position inside the list
 */
exports.getByIndex = ramda_1.curry(function (domain, index, state) {
    var data = exports.getList(domain, state);
    return ramda_1.nth(index, data);
});
/**
 * Get the elements inside a specified range
 */
exports.getRange = ramda_1.curry(function (domain, start, stop, state) {
    var data = exports.getList(domain, state);
    return data.slice(start, stop);
});
/**
 * Returns if the list contains the specified value
 */
exports.contains = ramda_1.curry(function (domain, value, state) {
    var data = exports.getList(domain, state);
    return data.includes(value);
});
/**
 * Returns the index of the first occurrence
 */
exports.getIndexOf = ramda_1.curry(function (domain, value, state) {
    var data = exports.getList(domain, state);
    return data.indexOf(value);
});
/**
 * Returns the number of times the value is inside the list
 */
exports.getOccurrencesOf = ramda_1.curry(function (domain, value, state) {
    var data = exports.getList(domain, state);
    return ramda_1.pipe(ramda_1.filter(ramda_1.equals(value)), ramda_1.length)(data);
});
//# sourceMappingURL=selectors.js.map